@@ -1,4 +1,4 @@
-# This is file ../spam0.23-0/R/xybind.R
+# This is file ../spam0.27-0/R/xybind.R
 # This file is part of the spam package, 
 #      http://www.math.uzh.ch/furrer/software/spam/
 # written and maintained by Reinhard Furrer.
@@ -187,7 +187,7 @@ function(...,deparse.level=0)
     if(Xdim[1]!=Ydim[1])
          stop("Arguments have differing numbers of rows, in cbind.spam()",call.=FALSE)
 
-    XYlen <- args[[1]]@rowpointers[Xdim[1]+1]+args[[2]]@rowpointers[Xdim[1]+1]-int2
+    XYlen <- args[[1]]@rowpointers[Xdim[1]+1]+args[[2]]@rowpointers[Xdim[1]+1]-2L
     z <- .Fortran("cbind", Xdim[2], Xdim[1], Ydim[2], XYlen,
                   args[[1]]@entries, args[[1]]@colindices, args[[1]]@rowpointers,
                   args[[2]]@entries, args[[2]]@colindices, args[[2]]@rowpointers,
