@@ -565,57 +565,6 @@ c-----------------------------------------------------------------------
       return
       end   
 
-c-----------------------------------------------------------------------
-      subroutine sortrows(nrow,a,ja,ia)
-
-      implicit none
-      integer nrow
-      integer ia(nrow+1),ja(*)
-      double precision  a(*)
-c     
-c     sorts the rows according to column entries
-c
-c On entry:
-c----------
-c     nrow    -- row dimension of the matrix
-c     a,ja,ia -- input matrix in sparse format
-c
-c On return:
-c-----------
-c     a,ja,ia -- cleaned matrix
-c
-c Notes: 
-c-------
-c     Reinhard Furrer 2006-09-13
-c-----------------------------------------------------------------------
-c     Local variables
-      integer i,j,k,ko,ipos
-      double precision  tmp
-c
-c
-
-c     .. order the entries according to column indices
-c     burble-sort is used
-c
-      do 190 i = 1, nrow
-         do 160 ipos = ia(i), ia(i+1)-1
-            do 150 j = ia(i+1)-1, ipos+1, -1
-               k = j - 1
-               if (ja(k).gt.ja(j)) then
-                  ko = ja(k)
-                  ja(k) = ja(j)
-                  ja(j) = ko
-                  tmp = a(k)
-                  a(k) = a(j)
-                  a(j) = tmp
-               endif
- 150        continue
- 160     continue
- 190  continue
-      return
-c---- end of sortrows --------------------------------------------------
-c-----------------------------------------------------------------------
-      end
 
       subroutine cleanspam(nrow,a,ja,ia,eps)
       
@@ -1726,93 +1675,6 @@ c-----------------------------------------------------------------------
 c-----------------------------------------------------------------------
  
 c-----------------------------------------------------------------------
-      subroutine triplet2csr(nrow,ncol,nnz,a,ir,jc,ao,jao,iao,eps)
-
-      implicit none
-      double precision a(*),ao(*),eps
-      integer nrow,ncol,nnz,ir(*),jc(*),jao(*),iao(*)
-
-      integer     newnnz,      k,  i, j, tmp1,tmp2 
-
-c-----------------------------------------------------------------------
-c  Triplet representation     to   Compressed Sparse Row
-c  Similar to coocsr from sparsekit
-c-----------------------------------------------------------------------
-c converts a matrix that is stored in coordinate format
-c  a, ir, jc into a row general sparse ao, jao, iao format.
-c
-c on entry:
-c---------
-c nrow  = row dimension of matrix
-c nrow  = col dimension of matrix
-c nnz   = number of nonzero elements in matrix
-c a,
-c ir,
-c jc    = matrix in coordinate format. a(k), ir(k), jc(k) store the nnz
-c         nonzero elements of the matrix with a(k) = actual real value of
-c         the elements, ir(k) = its row number and jc(k) = its column
-c         number. The order of the elements is arbitrary.
-c
-c on return:
-c-----------
-c nnz   = number of nonzero elements in matrix
-c ao, jao, iao = matrix in general sparse matrix format with ao
-c       continung the real values, jao containing the column indices,
-c       and iao being the pointer to the beginning of the row,
-c       in arrays ao, jao.
-c
-c------------------------------------------------------------------------
-
-c     cycle over all entries and count the number of elements in each row
-c     skip if larger than nrow and ncol. newnnz is actual number within
-c     matrix(nrow,ncol).
-      newnnz = 0
-      do  k=1, nnz
-         tmp1 = ir(k)
-         if (tmp1 .le. nrow) then
-            tmp2 = jc(k)
-            if (tmp2 .le. ncol) then
-               if (abs(a(k)) .gt. eps) then
-                  iao(tmp1) = iao(tmp1)+1
-                  newnnz = newnnz + 1
-                  if (newnnz.lt.k) then
-                    jc(newnnz) = tmp2 
-                    ir(newnnz) = tmp1 
-                    a(newnnz) = a(k) 
-                  endif
-               endif
-            endif
-         endif
-      enddo
-c Starting position of each row, essentially a cumsum of iao
-      k = 1
-      do j=1,nrow+1
-         tmp1 = iao(j)
-         iao(j) = k
-         k = k + tmp1
-      enddo
-c Go through the structure  once more. Fill in output matrix.
-c iao is miss used. 
-      do  k=1, newnnz
-         i = ir(k)
-         tmp1 = iao(i)
-         ao(tmp1) = a(k)  
-         jao(tmp1) = jc(k)
-         iao(i) = tmp1+1
-      enddo
-c Shift back iao
-      do j=nrow,1,-1
-         iao(j+1) = iao(j)
-      enddo 
-      iao(1) = 1
-
-c Sort the individual rows
-      call sortrows(nrow,ao,jao,iao)
-      nnz = newnnz
-      return
-c-----------------------------------------------------------------------
-      end
-c-----------------------------------------------------------------------
 
 
 
